<div id="system_load">
{{ system_load["load_1m"] }} / {{ system_load["load_5m"] }} / {{ system_load["load_15m"] }}
</div>
<script>
  window.BussDCC.on("ui.system.load.updated", (load) => {
    const d = document.getElementById("system_load");
    d.innerHTML = `${load["load_1m"].toFixed(1)} / ${load["load_5m"].toFixed(1)} / ${load["load_15m"].toFixed(1)}`;
  });
</script>
