{% extends "bussdcc_framework/bootstrap_layout/base.html" %}

{% block title %}System{% endblock %}
{% block app_name %}bussdcc-system{% endblock %}

{% block styles %}
  {{ super() }}
  <style>
    :root {
      --metric-cpu-user: #3b82f6;
      --metric-cpu-system: #f59e0b;
      --metric-cpu-iowait: #ef4444;
      --metric-cpu-idle: #6b7280;
      --metric-net-rx: #14b8a6;
      --metric-net-tx: #8b5cf6;
    }
  </style>
{% endblock %}

{% block scripts %}
  {{ super() }}
  {% include "bussdcc_framework/client/_client.html" %}
  {% include "bussdcc_framework/socketio/_socketio.html" %}
  {% include "bussdcc_framework/chartjs/_chartjs.html" %}
  <script src="{{ url_for('bussdcc_framework_formtree.static', filename='formtree.js') }}"></script>
{% endblock %}

{% block nav %}
  <nav class="navbar navbar-expand-lg bg-primary" data-bs-theme="dark">
    <div class="container">
      <a class="navbar-brand" href="{{ url_for("index") }}">BussDCC System</a>
      <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
        <span class="navbar-toggler-icon"></span>
      </button>
      <div class="collapse navbar-collapse" id="navbarSupportedContent">
        <ul class="navbar-nav me-auto mb-2 mb-lg-0">
          <li class="nav-item">
            <a class="nav-link {{ "active" if request.blueprint == "system" }}" aria-current="page" href="{{ url_for("system.index") }}">System</a>
          </li>
        </ul>
      </div>
    </div>
  </nav>
{% endblock %}
