<div id="disk">
  {{ disk_usage.percent }}% ({{ (disk_usage.used / (1024 * 1024)) | round | int }}MB / {{ (disk_usage.total / (1024 * 1024)) | round | int }}MB)
</div>
<script>
  window.BussDCC.on("ui.system.disk.usage.updated", (disk) => {
    const d = document.getElementById("disk");

    d.textContent = `${disk.percent.toFixed(1)}% (${(disk.used/1024**2).toFixed(0)}MB / ${(disk.total/1024**2).toFixed(0)}MB)`;
  });
</script>
